summaryrefslogtreecommitdiffstats
path: root/kig/objects/object_drawer.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/object_drawer.h')
-rw-r--r--kig/objects/object_drawer.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kig/objects/object_drawer.h b/kig/objects/object_drawer.h
index 6206522e..c9c962dd 100644
--- a/kig/objects/object_drawer.h
+++ b/kig/objects/object_drawer.h
@@ -64,11 +64,11 @@ public:
*/
void draw( const ObjectImp& imp, KigPainter& p, bool selected ) const;
/**
* returns whether the object \p imp contains coordinate \p p . This is
* dependent on whether it is shown ( when it will never contain
* anything ), and on its width..
*/
- bool contains( const ObjectImp& imp, const Coordinate& pt, const KigWidget& w, bool nv = false ) const;
+ bool tqcontains( const ObjectImp& imp, const Coordinate& pt, const KigWidget& w, bool nv = false ) const;
/**
* returns whether the object \p imp is in the rectangle \p r . This is
* dependent on whether it is shown and on its width..
@@ -64,11 +64,11 @@ public:
void draw( const ObjectImp& imp, KigPainter& p, bool selected ) const;
/**
- * returns whether the object \p imp contains coordinate \p p . This is
+ * returns whether the object \p imp tqcontains coordinate \p p . This is
* dependent on whether it is shown ( when it will never contain
* anything ), and on its width..